@@ -109,6 +109,13 @@ def _open_hdf5(path: upath.UPath, use_remfile: bool = True) -> h5py.File:
     return h5py.File(file, mode="r")
 
 
+def is_group(accessor) -> bool:
+    """
+    Check if the given accessor is a group (e.g. h5py.Group or zarr.Group).
+    """
+    return hasattr(accessor, "keys")
+
+
 class FileAccessor:
     """
     A wrapper that abstracts the storage backend (h5py.File, h5py.Group, or zarr.Group), forwarding
@@ -399,7 +406,6 @@ def _traverse_internal_paths(
             results[group.name] = group
         else:
             return {}
-    is_dataset = hasattr(group, "keys") and len(group) > 0
     shape = getattr(group, "shape", None)
     is_scalar = shape == () or shape == (1,)
     is_array = shape is not None and not is_scalar
@@ -428,7 +434,7 @@ def _traverse_internal_paths(
         pass
     if is_table and not include_table_columns:
         return results
-    if not is_dataset:
+    if not is_group(group) and len(group) > 0:
         return results
     for subpath in group.keys():
         try:
