@@ -743,11 +743,24 @@ def _get_table_column_accessors(
     file_path: lazynwb.types_.PathLike,
     table_path: str,
     use_thread_pool: bool = False,
+    skip_references: bool = True,
 ) -> dict[str, zarr.Array | h5py.Dataset]:
     """Get the accessor objects for each column of an NWB table, as a dict of zarr.Array or
     h5py.Dataset objects. Note that the data from each column is not read into memory.
 
     Optionally use a thread pool to speed up retrieval of the columns - faster for zarr files.
+
+    Parameters
+    ----------
+    file_path : lazynwb.types_.PathLike
+        Path to the NWB file to read from.
+    table_path : str
+        Path to the table within the NWB file, e.g. '/intervals/trials'
+    use_thread_pool : bool, default False
+        If True, a thread pool will be used to retrieve the columns for speed.
+    skip_references : bool, default True
+        If True, columns that include references to other objects within the NWB file (e.g. TimeSeriesReferenceVectorData) will be skipped.
+        These columns are added for convenience but are convoluted to interpret and impact performance when reading data from the cloud.
     """
     names_to_columns: dict[str, zarr.Array | h5py.Dataset] = {}
     t0 = time.time()
@@ -776,10 +789,37 @@ def _get_table_column_accessors(
             "file_create_date",
         ):
             names_to_columns[p] = root.get(p)
+        # add anything that lives in general/metadata
+        for p in root.get("general/metadata", {}).keys():
+            if p not in names_to_columns:
+                value = root.get(f"general/metadata/{p}")
+                if not lazynwb.file_io.is_group(value):
+                    names_to_columns[p] = value
+        # ensure we don't include any groups from general
+        names_to_columns = {
+            k: v for k, v in names_to_columns.items() if not lazynwb.file_io.is_group(v)
+        }
 
     logger.debug(
         f"retrieved {len(names_to_columns)} column accessors from {file_path!r}/{table_path} in {time.time() - t0:.2f} s ({use_thread_pool=})"
     )
+    if skip_references:
+        known_references = {
+            "timeseries": "TimeSeriesReferenceVectorData",
+        }
+        for name, neurodata_type in known_references.items():
+            if (
+                accessor := names_to_columns.get(name)
+            ) is not None and accessor.attrs.get("neurodata_type") == neurodata_type:
+                logger.debug(
+                    f"Skipping reference column {name!r} with neurodata_type {neurodata_type!r}"
+                )
+                del names_to_columns[name]
+                del names_to_columns[f"{name}_index"]
+    else:
+        raise NotImplementedError(
+            "Keeping references is not implemented yet: see https://pynwb.readthedocs.io/en/stable/pynwb.base.html#pynwb.base.TimeSeriesReferenceVectorData"
+        )
     return names_to_columns
 
 
@@ -819,12 +859,18 @@ def _get_table_length(
     file_path: lazynwb.types_.PathLike,
     table_path: str,
 ) -> int:
-    for _, column in _get_table_column_accessors(file_path, table_path).items():
-        if column.ndim == 1:
-            return column.shape[0]
-    raise NotImplementedError(
-        f"Could not determine length of table {table_path} in {file_path!r}: all columns are ndim arrays"
-    )
+    table_accessors = _get_table_column_accessors(file_path, table_path)
+    # first cycle through columns as if this is a regular DynamicTable:
+    for name, accessor in table_accessors.items():
+        if _is_nominally_indexed_column(name, table_accessors.keys()):
+            return table_accessors[f"{name}_index"].shape[0]
+        if accessor.ndim == 1:  # regular column
+            return accessor.shape[0]
+        if accessor.ndim == 0:  # metadata table
+            return 1
+    # at this point we have only ndim arrays, so we can either assume that the first dimension
+    # represents observations (e.g. timepoints in TimeSeries.data) or raise an error:
+    return accessor.shape[0]
 
 
 def _get_path_to_row_indices(df: pl.DataFrame) -> dict[str, list[int]]:
@@ -867,8 +913,7 @@ def _get_table_schema_helper(
             ) and name.endswith("_index"):
                 # skip the index columns
                 continue
-            if not hasattr(dataset, "dtype"):
-                # e.g. Group in h5py or zarr
+            if lazynwb.file_io.is_group(dataset):
                 continue
             if name == "starting_time" and _is_timeseries_with_rate(
                 column_accessors.keys()
